# Welcome to Earthkit-aggregate's documentation!

**earthkit-aggregate** is a library of software tools to support people working with climate and meteorology data

**earthkit-aggregate** includes methods for aggregating data in time and space
(e.g. indicators and risk factors).
It has been designed following the philosphy of Earthkit, hence the methods should be interoperable with any
data object understood by earthkit-data.

## Getting started

**earthkit-aggregate** is available from PyPi. To make use of the interoperable funcitonality you should ensure
that you have installed the dependancies of *earthkit-data*.

### Installation

```bash
pip install earthkit-aggregate
```

### Import and use

```python
>>> from earthkit import aggregate

```

```{toctree}
:caption: 'Contents:'
:maxdepth: 2

examples.md
API Reference <_api/index>
```

# Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`
